searchNodes=[{"doc":"A DSL for easily building dynamic, reusable components for your frontend framework in Elixir. defcontenttag :card, tag: :div, class: &quot;card&quot; card do &quot;Content!&quot; end #=&gt; &lt;div class=&quot;card&quot;&gt;Content!&lt;/div&gt; defcontenttag :alert, tag: :div, class: &quot;alert&quot;, variants: [ primary: [class: &quot;primary&quot;], success: [class: &quot;success&quot;] ] alert :primary, &quot;Alert!&quot; #=&gt; &lt;div class=&quot;alert alert-primary&quot;&gt;Alert!&lt;/div&gt; alert :primary, &quot;Alert!&quot;, class: &quot;extra&quot; #=&gt; &lt;div class=&quot;alert alert-primary extra&quot;&gt;Alert!&lt;/div&gt; alert :success, &quot;Alert!&quot; #=&gt; &lt;div class=&quot;alert alert-success&quot;&gt;Alert!&lt;/div&gt; Generated function clauses accept a block and a list of opts. alert :primary, class: &quot;extra&quot; do &quot;Alert!&quot; end #=&gt; &lt;div class=&quot;alert alert-primary extra&quot;&gt;Alert!&lt;/div&gt; Usage The lib defines two macros: deftag and defcontenttag. The deftag macro defines void components, those that do not accept their own content, like hr, while the defcontenttag macro defines components that accept their own content, like div. Function Delegation The :tag option accepts an atom and an anonymous function (when using defcontenttag), which allows you to generate components that defer execution to another function. This is useful if you want to use Phoenix.HTML.Link.link/2, for example. defcontenttag :list_group_item, tag: &amp;Phoenix.HTML.Link.link/2, class: &quot;list-group-item&quot; list_group_item &quot;Action&quot;, to: &quot;#&quot; #=&gt; &lt;a href=&quot;#&quot; class: &quot;list-group-item&quot;&gt;Action&lt;/a&gt; CSS Class The :class option is the base class of the component and is used to build variants and options. See the Variants section below for details. Variants A variant generates a name/3 function clause that takes the variant name as its first argument. Variants are a handy way to define the same component in different contexts. defcontenttag :button, tag: :button, class: &quot;btn&quot;, variants: [ success: [class: &quot;success&quot;], primary: [class: &quot;primary&quot;], dropdown: [ class: &quot;toggle-dropdown&quot;, prefix: false, data: [toggle: &quot;dropdown&quot;], aria: [haspopup: true, expanded: false] ] ] button :success do &quot;Success!&quot; end #=&gt; &lt;button class=&quot;btn btn-success&quot;&gt;Success!&lt;/button&gt; button :dropdown do &quot;Dropdown!&quot; end #=&gt; &lt;button class=&quot;btn toggle-dropdown&quot; data-toggle=&quot;dropdown&quot; aria-haspopup=&quot;true&quot; aria-expanded=&quot;false&quot;&gt;Dropdown!&lt;/button&gt; You can combine variants by passing a named option with a list. button variants: [:success, :dropdown] do &quot;Dropdown!&quot; end #=&gt; &lt;button class=&quot;btn btn-success toggle-dropdown&quot; data-toggle=&quot;dropdown&quot; aria-haspopup=&quot;true&quot; aria-expanded=&quot;false&quot;&gt;Dropdown!&lt;/button&gt; Merge Each declared variant has a :merge option that defaults to true. While it&#39;s handy for declaring contextual (class=&quot;alert alert-{success|danger}&quot;) variants that inherit the parent component class, sometimes you may want to customise or remove the component class. defcontenttag :dropdown, tag: :ul, class: &quot;dropdown&quot;, variants: [ dropup: [class: &quot;dropup&quot;, merge: false] ] dropdown :dropup do &quot;Dropup!&quot; end #=&gt; &lt;ul class=&quot;dropup&quot;&gt;...&lt;/ul&gt; dropdown :dropdown do &quot;Dropup!&quot; end #=&gt; &lt;ul class=&quot;dropdown&quot;&gt;...&lt;/ul&gt; Prefix The prefix is a shortcut for prefixing the component&#39;s class to the variant class. It default&#39;s to the component&#39;s :class option. The following three examples are equivalent. defcontenttag :alert, tag: :div, class: &quot;alert&quot;, variants: [ primary: [class: &quot;primary&quot;] ] defcontenttag :alert, tag: :div, class: &quot;alert&quot;, variants: [ primary: [class: &quot;alert-primary&quot;, prefix: false] ] defcontenttag :alert, tag: :div, class: &quot;alert&quot;, variants: [ primary: [class: &quot;primary&quot;, prefix: &quot;alert&quot;] ] Declaring Options You can declare a list of options that can be used during function calls. This is handy for combining with variants to create complex class combinations. defcontenttag :col, tag: :div, class: &quot;col&quot;, options: [:sm, :md, :lg, :auto] col auto: true, sm: 6, md: 4 do &quot;Col!&quot; end #=&gt; &lt;div class=&quot;col col-auto col-sm-6 col-md-4&quot;&gt;...&lt;/div&gt; In the above example, you may not want to use the col class since you are declaring col. In this case, combine with variants for the desired combinations. defcontenttag :col, tag: :div, class: &quot;col&quot;, variants: [ auto: [class: &quot;auto&quot;], sm: [class: &quot;sm&quot;], md: [class: &quot;md&quot;], lg: [class: &quot;lg&quot;], ], options: [:auto, :sm, :md, :lg] col :auto, sm: 6, md: 4 do &quot;Col!&quot; end #=&gt; &lt;div class=&quot;col-auto col-sm-6 col-md-4&quot;&gt;...&lt;/div&gt; Note that, options can: have their component&#39;s class prefixed; be passed true to use the option&#39;s name as the class rather than an explicit value. On Variants And Options While combining these options is powerful, sometimes it&#39;s best to go for simpliciy. The examples above can be declared as separate components. defcontenttag :col_auto, tag: :div, class: &quot;col-auto&quot;, options: [:auto, :sm, :md, :lg] defcontenttag :col_sm, tag: :div, class: &quot;col-sm&quot;, options: [:auto, :sm, :md, :lg] col_auto sm: 6, md: 4 do &quot;Col!&quot; end #=&gt; &lt;div class=&quot;col-auto col-sm-6 col-md-4&quot;&gt;...&lt;/div&gt; col_sm md: 4 do &quot;Col!&quot; end #=&gt; &lt;div class=&quot;col-sm col-md-4&quot;&gt;...&lt;/div&gt; Appending And Prepending Content You can append or prepend additional components to your component&#39;s content by using :append and/or :prepend. For example, a Bootstrap alert can have a close button. defcontenttag :close, tag: :button, wrap_content: :span, class: &quot;close&quot;, data: [dismiss: &quot;alert&quot;], aria: [label: &quot;Close&quot;] defcontenttag :alert, tag: :div, class: &quot;alert&quot;, prepend: close(&quot;&amp;times;&quot;), variants: [primary: [class: &quot;primary&quot;]] alert :primary do &quot;Content&quot; end &lt;div class=&quot;alert alert-primary&quot;&gt; &lt;button aria-label=&quot;Close&quot; class=&quot;close&quot; data-dismiss=&quot;alert&quot;&gt; &lt;span&gt;&amp;times;&lt;/span&gt; &lt;/button&gt; Content &lt;/div&gt; Both options accept an atom or a tuple in one the forms {:safe, iodata}, {:tag, opts}, {:tag, &quot;content&quot;}, and {:tag, &quot;content&quot;, opts}. Nesting Components The :parent option is useful for nesting a component in an additional tag. You can pass an atom, or a tuple with either a function or an atom, and a list of parent options. For example, breadcrumbs in Bootstrap are built with an ol tag wrapped in a nav tag. &lt;nav role=&quot;nav&quot;&gt; &lt;ol class=&quot;breadcrumbs&quot;&gt; &lt;li class=&quot;breadcrumbs-item&quot;&gt;...&lt;/li&gt; &lt;/ol&gt; &lt;/nav&gt; You can use the parent: :nav or parent: {:nav, [role: &quot;nav&quot;]} to address this case. defcontenttag :breadcrumbs, tag: :ol, ..., parent: :nav defcontenttag :breadcrumbs, tag: :ol, ..., parent: {:nav, [role: &quot;nav&quot;]} You can also pass an anonymouse function to the parent option. defcontenttag :breadcrumbs, tag: :ol, ..., parent: &amp;fun/1 Wrapping Content The :wrap_content option works exactly like the :parent option except that it wraps the content of the component rather than the component itself. For example, a Bootstrap button whose text is wrapped in a span. defcontenttag :button, tag: :button, ..., wrap_content: :span Default HTML Options Any additional options declared in the component definition are forwarded onto the underlying HTML. Default options can be overriden during function calls. Options :tag - the component&#39;s tag. Can be an atom or an anonymous function. :class - the component&#39;s class name. This option is required. :parent - wraps the component in the given tag. Accepts an atom, a anonymous function, or a tuple where the first element is the parent tag and the second is a list of parent options. For example, {:div, [class: &quot;something&quot;]}. :prepend - prepends the given tag to the component&#39;s content. Accepts a tuple in the following format: {:safe, iodata}, {:tag, opts}, {:tag, &quot;content&quot;}, or {:tag, &quot;content&quot;, opts}. For example, {:hr, [class: &quot;divider&quot;]} or {:button, &quot;Dropdown&quot;, class: &quot;extra&quot;}. :append - appends the given content to the component. See the :prepend option for usage. :wrap_content - wraps the inner content of the component in the given tag. See the :parent option for usage. :variants - a keyword list of component variants. Each variant generates a component/3 (component/2 for deftag) function clause where an atom variant name is the first argument. :options - a list of options that the component can accept, which generate additional classes.","ref":"ExComponent.html","title":"ExComponent","type":"module"},{"doc":"","ref":"ExComponent.html#defcontenttag/2","title":"ExComponent.defcontenttag/2","type":"macro"},{"doc":"","ref":"ExComponent.html#deftag/2","title":"ExComponent.deftag/2","type":"macro"},{"doc":"Contains configuration options. overridable_opts - a list of default component options that can be overridden during function calls.","ref":"ExComponent.Config.html","title":"ExComponent.Config","type":"module"},{"doc":"","ref":"ExComponent.Config.html#get_config/1","title":"ExComponent.Config.get_config/1","type":"function"}]